@@ -5,19 +5,27 @@
 #' @param ... Arguments to be passed to \code{\link[base]{message}}
 #' @param skip_before A \code{boolean}. Indicates if a line should be skipped before the message. 
 #' @param skip_after A \code{boolean}. Indicates if a line should be skipped after the message. 
+#' @param warn A \code{boolean}. Indicates whether a warning should be thrown.
 #' 
 #' @return None
 #' 
-#' @import stringr
+#' @importFrom stringr str_c
 
 
-msg <- function(..., skip_before=TRUE, skip_after=FALSE) {
+msg <- function(..., skip_before=TRUE, skip_after=FALSE, warn = FALSE) {
   
   m <- str_c("BETS-package: ", ...)
+  
   if(skip_before) k <- paste0("\n", m)
   if(skip_after) k <- paste0(m, "\n")
   Encoding(k) <- "UTF-8"
-  message(k)
+  
+  if(warn){
+    warning(k, call. = FALSE)
+  }
+  else {
+    message(k)
+  }
   
   invisible(m)
 }
